@@ -18,7 +18,7 @@
  * Author: Sergey Shekyan shekyan@gmail.com
  *
  * Slow HTTP attack vulnerability test tool
- *  http://code.google.com/p/slowhttptest/
+ *  https://github.com/shekyan/slowhttptest
  *****/
 #include "config.h"
 #include "slowhttptest.h"
@@ -86,14 +86,14 @@ static const char* user_agents[] = {
     "AppleWebKit/533.21.1 (KHTML, like Gecko) Version/5.0.5 Safari/533.21.1",
     "Mozilla/5.0 (Macintosh; Intel Mac OS X 10.7; rv:5.0.1) "
     "msnbot-131-253-46-102.search.msn.com",
-    "User-Agent: Mozilla/5.0 (Windows NT 6.1; WOW64; Trident/7.0; rv:11.0) like Gecko"
+    "Mozilla/5.0 (Windows NT 6.1; WOW64; Trident/7.0; rv:11.0) like Gecko"
     "AppleWebKit/534.30 (KHTML, like Gecko) Chrome/12.0.742.122 Safari/534.30",
     "Opera/9.80 (Macintosh; Intel Mac OS X 10.7.0; U; Edition MacAppStore; en) "
     "Mozilla/5.0 (Macintosh; Intel Mac OS X) AppleWebKit/534.34 (KHTML,like Gecko) PhantomJS/1.9.0 (development) Safari/534.34",
     "Mozilla/4.0 (compatible; MSIE 8.0; Windows NT 6.1; Trident/4.0; SLCC2)"
 };
 static const char referer[] = 
-    "Referer: https://github.com/shekyan/slowhttptest/\r\n";
+    "Referer: TESTING_PURPOSES_ONLY\r\n";
 static const char content_type_default[] = "Content-Type: application/x-www-form-urlencoded\r\n";
 static const char accept_default[] = "Accept: text/html;q=0.9,text/plain;q=0.8,image/png,*/*;q=0.5\r\n"; 
 static const char post_request[] = "Connection: close\r\n"
@@ -441,7 +441,7 @@ bool SlowHTTPTest::init(const char* url, const char* verb,
         test_info));
     dumpers_.push_back(new CSVDumper(csv_file_name,
         "Seconds,Closed,Pending,Connected,Service Available\n"));
-    for (int i = 0; i < dumpers_.size(); ++i) {
+    for (uint i = 0; i < dumpers_.size(); ++i) {
       if (!dumpers_[i]->Initialize()) {
         slowlog(LOG_FATAL, "Stat files cannot be opened for writing:\
             \n\t%s\n",
@@ -478,7 +478,7 @@ void SlowHTTPTest::report_parameters() {
   }
   if(eSlowRead != test_type_) {
       slowlog(LOG_INFO, "\n\t" cLCY PACKAGE " version " VERSION 
-      "\n - https://code.google.com/p/slowhttptest/ -\n"
+      "\n - https://github.com/shekyan/slowhttptest -\n"
       cBLU "test type:" cLBL "                        %s\n"
       cBLU "number of connections:" cLBL "            %d\n"
       cBLU "URL:" cLBL "                              %s\n"
@@ -505,7 +505,7 @@ void SlowHTTPTest::report_parameters() {
       );
   } else { // slow read
     slowlog(LOG_INFO, "\n\t" cLCY PACKAGE " version " VERSION 
-      "\n - https://code.google.com/p/slowhttptest/ -\n"
+      "\n - https://github.com/shekyan/slowhttptest -\n"
       cBLU "test type:" cLBL "                       %s\n"
       cBLU "number of connections:" cLBL "           %d\n"
       cBLU "URL:" cLBL "                             %s\n"
@@ -571,7 +571,7 @@ void SlowHTTPTest::report_status(bool to_stats) {
   }
 
   if(to_stats) {
-    for (int i = 0; i < dumpers_.size(); ++i) {
+    for (uint i = 0; i < dumpers_.size(); ++i) {
       dumpers_[i]->WriteStats("%d,%d,%d,%d,%d",
           seconds_passed_, 
           closed_,
